@@ -81,18 +81,16 @@ static bool init_run = false;
 static bool acct_shutdown = true;
 static int freq = 0;
 static pthread_t watch_node_thread_id = 0;
+static acct_gather_profile_timer_t *profile_timer =
+	&acct_gather_profile_timer[PROFILE_FILESYSTEM];
 
 static void *_watch_node(void *arg)
 {
-	int type = PROFILE_FILESYSTEM;
-
 #if HAVE_SYS_PRCTL_H
 	if (prctl(PR_SET_NAME, "acctg_fs", NULL, NULL, NULL) < 0) {
 		error("%s: cannot set my name to %s %m", __func__, "acctg_fs");
 	}
 #endif
-	(void) pthread_setcancelstate(PTHREAD_CANCEL_ENABLE, NULL);
-	(void) pthread_setcanceltype(PTHREAD_CANCEL_ASYNCHRONOUS, NULL);
 
 	while (init_run && acct_gather_profile_test()) {
 		/* Do this until shutdown is requested */
@@ -100,12 +98,10 @@ static void *_watch_node(void *arg)
 		(*(ops.node_update))();
 		slurm_mutex_unlock(&g_context_lock);
 
-		slurm_mutex_lock(&acct_gather_profile_timer[type].notify_mutex);
-		slurm_cond_wait(
-			&acct_gather_profile_timer[type].notify,
-			&acct_gather_profile_timer[type].notify_mutex);
-		slurm_mutex_unlock(&acct_gather_profile_timer[type].
-				   notify_mutex);
+		slurm_mutex_lock(&profile_timer->notify_mutex);
+		slurm_cond_wait(&profile_timer->notify,
+				&profile_timer->notify_mutex);
+		slurm_mutex_unlock(&profile_timer->notify_mutex);
 	}
 	return NULL;
 }
@@ -156,7 +152,7 @@ extern int acct_gather_filesystem_fini(void)
 		init_run = false;
 
 		if (watch_node_thread_id) {
-			pthread_cancel(watch_node_thread_id);
+			slurm_cond_signal(&profile_timer->notify);
 			pthread_join(watch_node_thread_id, NULL);
 		}
 
